Archiver interface
==================

Module contents
---------------

.. autoclass:: bact_archiver.archiver.ArchiverInterface
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: bact_archiver.archiver.ArchiverBasis
    :members:
    :undoc-members:
    :show-inheritance:
